﻿using Syncfusion.UI.Xaml.Controls.Layout;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at https://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace Docking_render
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        public Brush TabItemSelectedBackground
        {
            get { return (Brush)GetValue(TabItemSelectedBackgroundProperty); }
            set { SetValue(TabItemSelectedBackgroundProperty, value); }
        }

        // Using a DependencyProperty as the backing store for TabItemSelectedBackground.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty TabItemSelectedBackgroundProperty =
            DependencyProperty.Register("TabItemSelectedBackground", typeof(Brush), typeof(MainPage), new PropertyMetadata(new SolidColorBrush(Colors.Orange)));

        public Brush TabItemMouseOverBackground
        {
            get { return (Brush)GetValue(TabItemMouseOverBackgroundProperty); }
            set { SetValue(TabItemMouseOverBackgroundProperty, value); }
        }

        // Using a DependencyProperty as the backing store for TabItemMouseOverBackground.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty TabItemMouseOverBackgroundProperty =
            DependencyProperty.Register("TabItemMouseOverBackground", typeof(Brush), typeof(MainPage), new PropertyMetadata(new SolidColorBrush(Colors.DarkGreen)));



        public Brush TabItemUnselectedBackground
        {
            get { return (Brush)GetValue(TabItemUnselectedBackgroundProperty); }
            set { SetValue(TabItemUnselectedBackgroundProperty, value); }
        }

        // Using a DependencyProperty as the backing store for TabItemUnselectedBackground.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty TabItemUnselectedBackgroundProperty =
            DependencyProperty.Register("TabItemUnselectedBackground", typeof(Brush), typeof(MainPage), new PropertyMetadata(new SolidColorBrush(Colors.LightGreen)));



        public Brush DockTabPanelBackground
        {
            get { return (Brush)GetValue(DockTabPanelBackgroundProperty); }
            set { SetValue(DockTabPanelBackgroundProperty, value); }
        }

        // Using a DependencyProperty as the backing store for DockTabPanelBackground.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty DockTabPanelBackgroundProperty =
            DependencyProperty.Register("DockTabPanelBackground", typeof(Brush), typeof(MainPage), new PropertyMetadata(new SolidColorBrush(Colors.GreenYellow)));



        public static IEnumerable<T> FindVisualChildren<T>(DependencyObject parent)
        where T : DependencyObject
        {
            int childrenCount = VisualTreeHelper.GetChildrenCount(parent);
            for (int i = 0; i < childrenCount; i++)
            {
                var child = VisualTreeHelper.GetChild(parent, i);

                var childType = child as T;
                if (childType != null)
                {
                    yield return (T)child;
                }
                foreach (var other in FindVisualChildren<T>(child))
                {
                    yield return other;
                }
            }
        }

        private void docking_LayoutUpdated(object sender, object e)
        {
            foreach (DockTabControl control in FindVisualChildren<DockTabControl>(docking))
            {
                if (control.Items.Count > 1)
                {
                    foreach (DockTabPanel itemgrid in FindVisualChildren<DockTabPanel>(control))
                    {
                        itemgrid.Background = DockTabPanelBackground;
                    }

                    foreach (DockTabItem item in control.Items)
                    {
                        if (item.IsSelected)
                        {
                            foreach (Border border in FindVisualChildren<Border>(item))
                            {
                                if (border.Name == "SelectedBorder")
                                {
                                    border.Background = TabItemSelectedBackground;
                                }
                            }
                        }
                        else
                        {
                            foreach (Border border in FindVisualChildren<Border>(item))
                            {
                                if (border.Name == "SelectedBorder")
                                {
                                    border.Opacity = 0;
                                }
                            }
                        }
                        foreach (Grid itemgrid in FindVisualChildren<Grid>(item))
                        {
                            if (itemgrid.Name == "TemplateBottomSelected")
                            {
                                itemgrid.Background = TabItemUnselectedBackground;
                            }
                        }
                        item.PointerEntered += Item_PointerEntered;
                        item.PointerExited += Item_PointerExited;
                    }
                }
            }
        }

        private void Item_PointerExited(object sender, PointerRoutedEventArgs e)
        {
            if (!(sender as DockTabItem).IsSelected)
            {
                foreach (Border border in FindVisualChildren<Border>(sender as DockTabItem))
                {
                    if (border.Name == "SelectedBorder")
                    {
                        border.Opacity = 0;
                    }
                }
            }
        }

        private void Item_PointerEntered(object sender, PointerRoutedEventArgs e)
        {
            if (!(sender as DockTabItem).IsSelected)
            {
                foreach (Border border in FindVisualChildren<Border>(sender as DockTabItem))
                {
                    if (border.Name == "SelectedBorder")
                    {
                        border.Background = TabItemMouseOverBackground;
                        border.Opacity = 1;
                    }
                }
            }
        }
    }
}
